@@ -188,16 +188,20 @@ class account():
             if (older == False):
                 if self.accountdata.last_id == None:
                     data = self.api.GetFriendsTimeline()
+                    rtdata = self.api.GetRetweets_to_user()
                 else:
                     print "refreshing since" + str(self.accountdata.last_id)
                     data = self.api.GetFriendsTimeline(since_id=self.accountdata.last_id)
+                    rtdata = self.api.GetRetweets_to_user(since_id=self.accountdata.last_id)
             else:
                 if self.accountdata.oldest_id == None:
                     data = self.api.GetFriendsTimeline(count=get_count)
+                    rtdata = self.api.GetRetweets_to_user(count=get_count)
                 else:
                     print "refreshing prior to" + str(self.accountdata.oldest_id)
                     data = self.api.GetFriendsTimeline(max_id=self.accountdata.oldest_id, count=get_count)
-
+                    rtdata = self.api.GetRetweets_to_user(max_id=self.accountdata.oldest_id, count=get_count)
+            data += rtdata
             for x in data:
                  if (self.accountdata.last_id != None):
                     if (x.id == self.accountdata.last_id):
@@ -946,7 +950,7 @@ class account():
         if (os.path.isfile("/home/user/.witterPics/" + self.accountdata.servicename + "/" + filename)):
             try:
                 pixbuf = gtk.gdk.pixbuf_new_from_file("/home/user/.witterPics/" + self.accountdata.servicename + "/" + filename)
-            except GError:
+            except gobject.GError:
                 #failed to load file, delete it, and go fetch a new one
                 print "corrupted avatar file found, deleting it"
                 os.remove("/home/user/.witterPics/" + self.accountdata.servicename + "/" + filename)
