@@ -1470,6 +1470,67 @@ class Api(object):
     self._CheckForTwitterError(data)
     return [Status.NewFromJsonDict(x) for x in data]
 
+  def GetRetweets_to_user(self,
+                      since_id=None,
+                      max_id=None,
+                      count=None,
+                      page=None):
+    '''Fetch the sequence of retweets made by users friends
+
+    The twitter.Api instance must be authenticated if the user is private.
+
+    Args:
+      
+      since_id:
+        Returns only public statuses with an ID greater than (that is,
+        more recent than) the specified ID. [optional]
+      max_id:
+        Returns only statuses with an ID less than (that is, older
+        than) or equal to the specified ID. [optional]
+      count:
+        Specifies the number of statuses to retrieve. May not be
+        greater than 200.  [optional]
+      page:
+         Specifies the page of results to retrieve. Note: there are
+         pagination limits. [optional]
+
+    Returns:
+      A sequence of Status instances, one for each message up to count
+    '''
+    parameters = {}
+
+    url = self._base_url + 'statuses/retweeted_to_me.json'
+    
+
+    if since_id:
+      try:
+        parameters['since_id'] = long(since_id)
+      except:
+        raise TwitterError("since_id must be an integer")
+
+    if max_id:
+      try:
+        parameters['max_id'] = long(max_id)
+      except:
+        raise TwitterError("max_id must be an integer")
+
+    if count:
+      try:
+        parameters['count'] = int(count)
+      except:
+        raise TwitterError("count must be an integer")
+
+    if page:
+      try:
+        parameters['page'] = int(page)
+      except:
+        raise TwitterError("page must be an integer")
+
+    json = self._FetchUrl(url, parameters=parameters)
+    data = simplejson.loads(json)
+    self._CheckForTwitterError(data)
+    return [Status.NewFromJsonDict(x) for x in data]
+
   def GetStatus(self, id):
     '''Returns a single status message.
 
@@ -1581,7 +1642,7 @@ class Api(object):
     results.append(self.PostUpdate(lines[-1], **kwargs))
     return results
 
-  def GetReplies(self, since=None, since_id=None, page=None):
+  def GetReplies(self, since=None, since_id=None, page=None, max_id=None,count=None,):
     '''Get a sequence of status messages representing the 20 most recent
     replies (status updates prefixed with @username) to the authenticating
     user.
@@ -1606,6 +1667,10 @@ class Api(object):
       parameters['since'] = since
     if since_id:
       parameters['since_id'] = since_id
+    if max_id:
+      parameters['max_id'] = max_id
+    if since_id:
+      parameters['count'] = count
     if page:
       parameters['page'] = page
     json = self._FetchUrl(url, parameters=parameters)
