@@ -247,7 +247,8 @@ class Witter():
     def FollowTweetAuthor(self, widget):
         #TODO : put this on a thread
         self.activeAcount.FollowUser(widget, self.reply_to_name)
-
+        refreshtask = witter.RefreshTask(self.followUserWrapper, 0, None)
+        refreshtask.refresh()
 
 
     def UnFollowTweetAuthor(self, widget):
@@ -544,6 +545,7 @@ class Witter():
             print "written config object to file"
         except IOError, e:
             print "failed to write ConfigObject"
+       
 
 
     def createConfig(self):
@@ -771,6 +773,10 @@ class Witter():
         self.ui.setTweetText("")
         self.ui.showBusy(-1)
 
+    def followUserWrapper(self, get_older=False, more=0, autoval=None):
+        self.ui.showBusy(1)
+        self.activeAcount.FollowUser(widget, self.reply_to_name)
+        self.ui.showBusy(-1)
 
 
     def getTrendsWrapper(self, get_older=False, autoval=None, more=0, *args):
@@ -945,8 +951,16 @@ class Witter():
     def cb_switch_view(self, interface, method, args, user_data):
          if method == 'open_mentions':
             self.ui.switchViewTo(self.ui.treeview,"mentions")
+            self.ui.window.show()
+            #self.ui.window.fullscreen()
+            #self.ui.window.setActiveWindow()
+
          if method == 'open_dm':
             self.ui.switchViewTo(self.ui.treeview,"direct")
+            self.ui.window.show()
+            #self.ui.window.fullscreen()
+            
+            #self.ui.window.setActiveWindow()
             
     def _on_orientation_signal(self, orientation, stand, face, x, y, z):
          if (orientation == 'portrait'):
